@@ -49,7 +49,7 @@ def totp(key, format='dec6', period=30, t=None, hash=hashlib.sha1):
        :type: str
     '''
     if t is None:
-        t = time.time()
+        t = int(time.time())
     else:
         if isinstance(t, datetime.datetime):
             t = calendar.timegm(t.utctimetuple())
@@ -58,7 +58,7 @@ def totp(key, format='dec6', period=30, t=None, hash=hashlib.sha1):
     T = int(t/period)
     return hotp(key, T, format=format, hash=hash)
 
-def accept_totp( response, key, format='dec6', period=30, t=None,
+def accept_totp(key, response, format='dec6', period=30, t=None,
         hash=hashlib.sha1, forward_drift=1, backward_drift=1, drift=0):
     '''
        Validate a TOTP value inside a window of 
@@ -120,8 +120,9 @@ def accept_totp( response, key, format='dec6', period=30, t=None,
            reliable source of time like an NTP server.
        :rtype: a two element tuple
     '''
-    t = t or time.time()
-    for i in range(-backward_drift,forward_drift+1):
+    if t is None:
+        t = int(time.time())
+    for i in range(max(-divmod(t, period)[0],-backward_drift),forward_drift+1):
         d = (drift+i) * period
         if totp(key, format=format, period=period, hash=hash, t=t+d) == str(response):
             return True, drift+i
